package youngee_talent_model

import (
	"github.com/gogf/gf/util/gmeta"

	"github.com/gogf/gf/os/gtime"
)

type PlatformInfo struct {
	gmeta.Meta   `orm:"table:info_third_platform"`
	PlatformId   int    `json:"platform_id"`
	PlatformIcon string `json:"platform_icon"`
	PlatformName string `json:"platform_name"`
}

type ProductInfo struct {
	gmeta.Meta    `orm:"table:younggee_product"`
	ProductId     int             `json:"product_id"`     // 商品id
	ProductName   string          `json:"product_name"`   // 商品名称
	ProductType   int             `json:"product_type"`   // 商品类型
	ShopAddress   string          `json:"shop_address"`   // 店铺地址，商品类型为线下品牌时需填写
	ProductPrice  int64           `json:"product_price"`  // 商品价值
	ProductDetail string          `json:"product_detail"` // 商品详情
	ProductUrl    string          `json:"product_url"`    // 商品链接，可为电商网址、公司官网、大众点评的店铺地址等可以说明商品信息或者品牌信息的线上地址；
	BrandName     string          `json:"brand_name"`     // 品牌名称
	ProductPhoto  []*ProductPhoto `orm:"with:product_id=product_id"`
}

type ProductPhoto struct {
	gmeta.Meta     `orm:"table:younggee_product_photo"`
	ProductPhotoId int    `json:"product_photo_id"` // 商品图片id
	PhotoUrl       string `json:"photo_url"`        // 图片或视频url
	Symbol         int    `json:"symbol"`           // 图片为主图或详情图标志位，1为主图，2为详情图，3为视频
	ProductId      int    `json:"product_id"`       // 所属商品id
}

type RecruitStrategy struct {
	gmeta.Meta        `orm:"table:recruit_strategy"`
	RecruitStrategyId int `json:"recruit_strategy_id"` // 招募策略id
	FeeForm           int `json:"fee_form"`            // 稿费形式，1-3分别代表产品置换、固定稿费、自报价
	StrategyId        int `json:"strategy_id"`         // 策略id
	FollowersLow      int `json:"followers_low"`       // 达人粉丝数下限
	FollowersUp       int `json:"followers_up"`        // 达人粉丝数上限
	RecruitNumber     int `json:"recruit_number"`      // 招募数量
	Offer             int `json:"offer"`               // 报价
	ProjectId         int `json:"project_id"`          // 所属项目id
}

type ProjectPhoto struct {
	gmeta.Meta     `orm:"table:project_photo"`
	ProjectPhotoId int    `json:"project_photo_id"` // 项目图片id
	PhotoUrl       string `json:"photo_url"`        // 图片url
	PhotoUid       string `json:"photo_uid"`        //
	ProjectId      int    `json:"project_id"`       // 所属项目id
}

type ProjectDetail struct {
	gmeta.Meta      `orm:"table:project_info"`
	ProjectId       int                `json:"project_id"`       // 项目id
	ProjectName     string             `json:"project_name"`     // 项目名称
	ProjectType     int                `json:"project_type"`     // 项目类型，1代表全流程项目，2代表专项项目
	ProjectPlatform int                `json:"project_platform"` // 项目平台，1-7分别代表小红书、抖音、微博、快手、b站、大众点评、知乎
	ProjectForm     int                `json:"project_form"`     // 项目形式，1-4分别代表实体商品寄拍、虚拟产品测评、线下探店打卡、素材微原创
	TalentType      string             `json:"talent_type"`      // 达人类型
	RecruitDdl      *gtime.Time        `json:"recruit_ddl"`      // 招募截止时间
	ContentType     int                `json:"content_type"`     // 内容形式，1代表图文，2代表视频
	ProjectDetail   string             `json:"project_detail"`   // 项目详情
	ApplyNum        int                `json:"apply_num"`        // 报名人数
	ProductId       int                `json:"product_id"`       // 关联商品id
	Product         *ProductInfo       `orm:"with:product_id=product_id"`
	ProjectPhoto    []*ProjectPhoto    `orm:"with:project_id=project_id"` // 项目详情图
	RecruitStrategy []*RecruitStrategy `orm:"with:project_id=project_id"` // 招募策略
	PlatformInfo    *PlatformInfo      `orm:"with:platform_id=project_platform"`
}
